@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -31,7 +31,7 @@
 using namespace GrantleeTheme;
 
 QSharedPointer<GrantleeKi18nLocalizer> GrantleeTheme::ThemePrivate::sLocalizer;
-Grantlee::Engine *GrantleeTheme::ThemePrivate::sEngine = Q_NULLPTR;
+Grantlee::Engine *GrantleeTheme::ThemePrivate::sEngine = nullptr;
 
 ThemePrivate::ThemePrivate()
     : QSharedData()
